==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/eo.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Konservejo dumtempe ne disponeblas",
    "Storage invalid" : "Konservejo ne validas",
    "Unknown error" : "Nekonata eraro",
    "All files" : "Ĉiuj dosieroj",
    "Recent" : "Lastaj ŝanĝoj",
    "Favorites" : "Pliŝatataj",
    "File could not be found" : "Dosiero ne troveblas",
    "Move or copy" : "Movi aŭ kopii",
    "Download" : "Elŝuti",
    "Delete" : "Forigi",
    "Home" : "Hejmo",
    "Close" : "Fermi",
    "Could not create folder \"{dir}\"" : "Ne eblas krei dosierujon „{dir}“",
    "This will stop your current uploads." : "Tio haltigos viajn nunajn alŝutojn.",
    "Upload cancelled." : "La alŝuto nuliĝis.",
    "Processing files …" : "Traktado de dosieroj…",
    "…" : "… ",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ne povis alŝuti {filename} ĉar ĝi estas dosierujo aŭ ĝi havas 0 bajtoj",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ne sufiĉas libera spaco: vi alŝutas {size1} sed nur {size2} restas",
    "Target folder \"{dir}\" does not exist any more" : "Cela dosierujo \"{dir}\" ne plu ekzistas",
    "Not enough free space" : "Ne sufiĉe libera spaco",
    "An unknown error has occurred" : "Nekonata eraro okazis",
    "Uploading …" : "Alŝutante…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} el {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Alŝuto de tiu elemento ne estas subtenata",
    "Target folder does not exist any more" : "La cela dosierujo ne plu ekzistas",
    "Error when assembling chunks, status code {status}" : "Eraro dum kunigo de pecoj, stata kodo {status}",
    "Actions" : "Agoj",
    "Rename" : "Alinomi",
    "Copy" : "Kopii",
    "Choose target folder" : "Elekti celan dosierujon",
    "Open" : "Malfermi",
    "Disconnect storage" : "Malkonekti konservejon",
    "Unshare" : "Malkunhavigi",
    "Could not load info for file \"{file}\"" : "Informo pri dosiero „{file}“ ne legeblis",
    "Files" : "Dosieroj",
    "Details" : "Detaloj",
    "Select" : "Elekti",
    "Pending" : "Pritraktotaj",
    "Unable to determine date" : "Ne eblas determini daton",
    "This operation is forbidden" : "Ĉi tiu operacio malpermesatas",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ĉi tiu dosierujo maldisponeblas, bonvolu kontroli la protokolojn aŭ kontakti la administranton",
    "Could not move \"{file}\", target exists" : "Ne eblas movi la dosieron „{file}“, celo jam ekzistas",
    "Could not move \"{file}\"" : "Ne eblas movi la dosieron „{file}“",
    "copy" : "kopio",
    "Could not copy \"{file}\", target exists" : "Ne eblas kopii la dosieron „{file}“, celo jam ekzistas",
    "Could not copy \"{file}\"" : "Ne eblas kopii la dosieron „{file}“",
    "Copied {origin} inside {destination}" : "{origin} kopiita ene de {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} kaj {nbfiles} aliaj dosieroj kopiitaj ene de {destination}",
    "{newName} already exists" : "{newName} jam ekzistas",
    "Could not rename \"{fileName}\", it does not exist any more" : "Ne eblis alinomi „{fileName}“, ĝi ne plu ekzistas",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "La nomo „{targetName}“ jam uzatas en la dosierujo „{dir}“. Bonvolu elekti alian nomon.",
    "Could not rename \"{fileName}\"" : "Ne eblis alinomi „{fileName}“",
    "Could not create file \"{file}\"" : "Ne eblas krei dosieron „{file}“",
    "Could not create file \"{file}\" because it already exists" : "Ne eblis krei dosieron „{file}“ ĉar ĝi jam ekzistas",
    "Could not create folder \"{dir}\" because it already exists" : "Ne eblas krei dosierujon „{dir}“ ĉar ĝi jam ekzistas",
    "Error deleting file \"{fileName}\"." : "Eraro dum forigo de dosiero „{fileName}“.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Neniu serĉorezulto en aliaj dosierujoj pri {tag}{filter}{endtag}",
    "Name" : "Nomo",
    "Size" : "Grando",
    "Modified" : "Modifita",
    "_%n folder_::_%n folders_" : ["%n dosierujo","%n dosierujoj"],
    "_%n file_::_%n files_" : ["%n dosiero","%n dosieroj"],
    "{dirs} and {files}" : "{dirs} kaj {files}",
    "_including %n hidden_::_including %n hidden_" : ["inkluzive %n kaŝita","inkluzive %n kaŝita(j)"],
    "You don’t have permission to upload or create files here" : "Vi ne permesatas alŝuti aŭ krei dosierojn ĉi tie",
    "_Uploading %n file_::_Uploading %n files_" : ["Alŝutatas %n dosiero","Alŝutatas %n dosieroj"],
    "New" : "Nova",
    "Select file range" : "Elekti dosierintervalon",
    "{used} of {quota} used" : "{used} uzataj el {quota}",
    "{used} used" : "{used} uzataj",
    "\"{name}\" is an invalid file name." : "„{name}“ estas nevalida dosiernomo.",
    "File name cannot be empty." : "Dosiernomo devas ne malpleni.",
    "\"/\" is not allowed inside a file name." : "Ne eblas uziĝi „/“ en dosiernomo.",
    "\"{name}\" is not an allowed filetype" : "„{name}“ ne estas permesita dosiertipo.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Konservejo de {owner} plenas; dosieroj ne povas alŝutiĝi aŭ sinkroniĝi plu!",
    "Your storage is full, files can not be updated or synced anymore!" : "Via konservejo plenas, ne plu eblas ĝisdatigi aŭ sinkronigi dosierojn!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Konservejo de {owner} preskaŭ plenas ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Via konservejo preskaŭ plenas ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["kongruas kun “{filter}”","kongruas kun “{filter}”"],
    "View in folder" : "Vidi en dosierujo",
    "Copied!" : "Kopiita!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopii senperan ligilon (nur validas por uzantoj, kiuj povas aliri al tiu dosiero aŭ dosierujo)",
    "Path" : "Vojo",
    "_%n byte_::_%n bytes_" : ["%n bajto","%n bajtoj"],
    "Favorited" : "Pliŝatitaj",
    "Favorite" : "Pliŝatata",
    "You can only favorite a single file or folder at a time" : "Vi povas samtempe pliŝatigi nur unu dosieron aŭ dosierujon",
    "New folder" : "Nova dosierujo",
    "Upload file" : "Alŝuti dosieron",
    "Not favorited" : "Ne pliŝatitaj",
    "Remove from favorites" : "Malpliŝatigi",
    "Add to favorites" : "Pliŝatigi",
    "An error occurred while trying to update the tags" : "Okazis eraro dum provo ĝisdatigi la etikedojn",
    "Added to favorites" : "Aldonita al pliŝatataĵoj",
    "Removed from favorites" : "Forigita el pliŝataĵoj",
    "You added {file} to your favorites" : "Vi aldonis {file} al viaj pliŝataĵoj",
    "You removed {file} from your favorites" : "Vi forigis {file} el viaj pliŝataĵoj",
    "File changes" : "Dosierŝanĝoj",
    "Created by {user}" : "Kreita de {user}",
    "Changed by {user}" : "Ŝanĝita de {user}",
    "Deleted by {user}" : "Forigita de {user}",
    "Restored by {user}" : "Restaŭrita de {user}",
    "Renamed by {user}" : "Alinomita de {user}",
    "Moved by {user}" : "Movita de {user}",
    "\"remote user\"" : "„fora uzanto“",
    "You created {file}" : "Vi kreis „{file}“",
    "You created an encrypted file in {file}" : "Vi kreis ĉifritan dosieron en {file}",
    "{user} created {file}" : "{user} kreis {file}",
    "{user} created an encrypted file in {file}" : "{user} kreis ĉifritan dosieron en {file}",
    "{file} was created in a public folder" : "{file} kreiĝis en publika dosierujo",
    "You changed {file}" : "Vi ŝanĝis {file}",
    "You changed an encrypted file in {file}" : "Vi ŝanĝis ĉifritan dosieron en {file}",
    "{user} changed {file}" : "{user} ŝanĝis {file}",
    "{user} changed an encrypted file in {file}" : "{user} ŝanĝis ĉifritan dosieron en {file}",
    "You deleted {file}" : "Vi forigis {file}",
    "You deleted an encrypted file in {file}" : "Vi forigis ĉifritan dosieron en {file}",
    "{user} deleted {file}" : "{user} forigis {file}",
    "{user} deleted an encrypted file in {file}" : "{user} forigis ĉifritan dosieron en {file}",
    "You restored {file}" : "Vi restaŭris {file}",
    "{user} restored {file}" : "{user} restaŭris {file}",
    "You renamed {oldfile} to {newfile}" : "Vi alinomis {oldfile} al {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} alinomis {oldfile} al {newfile}",
    "You moved {oldfile} to {newfile}" : "Vi movis {oldfile} al {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} movis {oldfile} al {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Dosiero aldoniĝis aŭ foriĝis el viaj <strong>pliŝataĵoj</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Dosiero aŭ dosierujo <strong>ŝanĝiĝis</strong> aŭ <strong>alinomiĝis</strong>",
    "A new file or folder has been <strong>created</strong>" : "Nova dosiero aŭ dosierujo <strong>kreiĝis</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Dosiero aŭ dosierujo <strong>foriĝis</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limigi sciigojn pri kreo aŭ ŝanĝo de viaj <strong>pliŝatataj dosieroj</strong> <em>(nur en la fluo)</em>",
    "A file or folder has been <strong>restored</strong>" : "Dosiero aŭ dosierujo <strong>restaŭrita</strong>",
    "Unlimited" : "Senlima",
    "Upload (max. %s)" : "Alŝuti (maks. %s)",
    "File Management" : "Dosieradministrado",
    "%s used" : "%s uzataj",
    "%1$s of %2$s used" : "%1$s uzataj el %2$s",
    "Settings" : "Agordo",
    "Show hidden files" : "Montri kaŝitajn dosierojn",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Uzu tiun adreson por <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">atingi viajn dosierojn per WebDAV</a>",
    "Toggle grid view" : "Baskuligi kradan vidon",
    "No files in here" : "Neniu dosiero ĉi tie",
    "Upload some content or sync with your devices!" : "Alŝutu iom da enhavo aŭ sinkronigu kun viaj aparatoj!",
    "No entries found in this folder" : "Neniu enigo troviĝis en ĉi tiu dosierujo",
    "Select all" : "Elekti ĉion",
    "Upload too large" : "Alŝuto tro granda",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "La dosieroj, kiujn vi provas alŝuti, transpasas la maksimuman grandon por dosieralŝutoj en ĉi tiu servilo.",
    "No favorites yet" : "Ankoraŭ neniu pliŝataĵo",
    "Files and folders you mark as favorite will show up here" : "Dosieroj kaj dosierujoj, kiujn vi markas kiel pliŝataĵoj, aperos ĉi tie",
    "Tags" : "Etikedoj",
    "Deleted files" : "Forigitaj dosieroj",
    "Shares" : "Kunhavigoj",
    "Shared with others" : "Kunhavata kun aliaj",
    "Shared with you" : "Kunhavata kun vi",
    "Shared by link" : "Kunhavata per ligilo",
    "Deleted shares" : "Forigitaj kunhavigoj",
    "Text file" : "Tekstodosiero",
    "New text file.txt" : "Nova tekstodosiero.txt",
    "Target folder" : "Cela dosierujo",
    "File handling" : "Dosiertraktado",
    "Maximum upload size" : "Maksimuma alŝutogrando",
    "max. possible: " : "maks. ebla: ",
    "Save" : "Konservi",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Per PHP-FPM, ŝanĝoj povas postuli 5 minutojn por aplikiĝi.",
    "Missing permissions to edit from here." : "Mankas permesoj por redakti ekde ĉi tie.",
    "%s of %s used" : "%s uzataj el %s",
    "Cancel upload" : "Nuligi alŝuton",
    "%1$s%% of %2$s used" : "%1$s%% el %2$s uzataj"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/eo.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Konservejo dumtempe ne disponeblas",
    "Storage invalid" : "Konservejo ne validas",
    "Unknown error" : "Nekonata eraro",
    "All files" : "Ĉiuj dosieroj",
    "Recent" : "Lastaj ŝanĝoj",
    "Favorites" : "Pliŝatataj",
    "File could not be found" : "Dosiero ne troveblas",
    "Move or copy" : "Movi aŭ kopii",
    "Download" : "Elŝuti",
    "Delete" : "Forigi",
    "Home" : "Hejmo",
    "Close" : "Fermi",
    "Could not create folder \"{dir}\"" : "Ne eblas krei dosierujon „{dir}“",
    "This will stop your current uploads." : "Tio haltigos viajn nunajn alŝutojn.",
    "Upload cancelled." : "La alŝuto nuliĝis.",
    "Processing files …" : "Traktado de dosieroj…",
    "…" : "… ",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ne povis alŝuti {filename} ĉar ĝi estas dosierujo aŭ ĝi havas 0 bajtoj",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ne sufiĉas libera spaco: vi alŝutas {size1} sed nur {size2} restas",
    "Target folder \"{dir}\" does not exist any more" : "Cela dosierujo \"{dir}\" ne plu ekzistas",
    "Not enough free space" : "Ne sufiĉe libera spaco",
    "An unknown error has occurred" : "Nekonata eraro okazis",
    "Uploading …" : "Alŝutado…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} el {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Alŝuto de tiu elemento ne estas subtenata",
    "Target folder does not exist any more" : "La cela dosierujo ne plu ekzistas",
    "Error when assembling chunks, status code {status}" : "Eraro dum kunigo de pecoj, stata kodo {status}",
    "Actions" : "Agoj",
    "Rename" : "Alinomi",
    "Copy" : "Kopii",
    "Choose target folder" : "Elekti celan dosierujon",
    "Open" : "Malfermi",
    "Delete file" : "Forigi dosieron",
    "Delete folder" : "Forigi dosierujon",
    "Disconnect storage" : "Malkonekti konservejon",
    "Unshare" : "Malkunhavigi",
    "Could not load info for file \"{file}\"" : "Informo pri dosiero „{file}“ ne legeblis",
    "Files" : "Dosieroj",
    "Details" : "Detaloj",
    "Select" : "Elekti",
    "Pending" : "Pritraktotaj",
    "Unable to determine date" : "Ne eblas determini daton",
    "This operation is forbidden" : "Ĉi tiu operacio malpermesatas",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ĉi tiu dosierujo maldisponeblas, bonvolu kontroli la protokolojn aŭ kontakti la administranton",
    "Could not move \"{file}\", target exists" : "Ne eblas movi la dosieron „{file}“, celo jam ekzistas",
    "Could not move \"{file}\"" : "Ne eblas movi la dosieron „{file}“",
    "copy" : "kopio",
    "Could not copy \"{file}\", target exists" : "Ne eblas kopii la dosieron „{file}“, celo jam ekzistas",
    "Could not copy \"{file}\"" : "Ne eblas kopii la dosieron „{file}“",
    "Copied {origin} inside {destination}" : "{origin} kopiita ene de {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} kaj {nbfiles} aliaj dosieroj kopiitaj ene de {destination}",
    "{newName} already exists" : "{newName} jam ekzistas",
    "Could not rename \"{fileName}\", it does not exist any more" : "Ne eblis alinomi „{fileName}“, ĝi ne plu ekzistas",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "La nomo „{targetName}“ jam uzatas en la dosierujo „{dir}“. Bonvolu elekti alian nomon.",
    "Could not rename \"{fileName}\"" : "Ne eblis alinomi „{fileName}“",
    "Could not create file \"{file}\"" : "Ne eblas krei dosieron „{file}“",
    "Could not create file \"{file}\" because it already exists" : "Ne eblis krei dosieron „{file}“ ĉar ĝi jam ekzistas",
    "Could not create folder \"{dir}\" because it already exists" : "Ne eblas krei dosierujon „{dir}“ ĉar ĝi jam ekzistas",
    "Error deleting file \"{fileName}\"." : "Eraro dum forigo de dosiero „{fileName}“.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Neniu serĉorezulto en aliaj dosierujoj pri {tag}{filter}{endtag}",
    "Name" : "Nomo",
    "Size" : "Grando",
    "Modified" : "Modifita",
    "_%n folder_::_%n folders_" : ["%n dosierujo","%n dosierujoj"],
    "_%n file_::_%n files_" : ["%n dosiero","%n dosieroj"],
    "{dirs} and {files}" : "{dirs} kaj {files}",
    "_including %n hidden_::_including %n hidden_" : ["inkluzive %n kaŝita","inkluzive %n kaŝita(j)"],
    "You don’t have permission to upload or create files here" : "Vi ne permesatas alŝuti aŭ krei dosierojn ĉi tie",
    "_Uploading %n file_::_Uploading %n files_" : ["Alŝutatas %n dosiero","Alŝutatas %n dosieroj"],
    "New" : "Nova",
    "Select file range" : "Elekti dosierintervalon",
    "{used} of {quota} used" : "{used} uzataj el {quota}",
    "{used} used" : "{used} uzataj",
    "\"{name}\" is an invalid file name." : "„{name}“ estas nevalida dosiernomo.",
    "File name cannot be empty." : "Dosiernomo devas ne malpleni.",
    "\"/\" is not allowed inside a file name." : "Ne eblas uziĝi „/“ en dosiernomo.",
    "\"{name}\" is not an allowed filetype" : "„{name}“ ne estas permesita dosiertipo.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Konservejo de {owner} plenas; dosieroj ne povas alŝutiĝi aŭ sinkroniĝi plu!",
    "Your storage is full, files can not be updated or synced anymore!" : "Via konservejo plenas, ne plu eblas ĝisdatigi aŭ sinkronigi dosierojn!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Konservejo de {owner} preskaŭ plenas ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Via konservejo preskaŭ plenas ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["kongruas kun “{filter}”","kongruas kun “{filter}”"],
    "View in folder" : "Vidi en dosierujo",
    "Copied!" : "Kopiita!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopii senperan ligilon (nur validas por uzantoj, kiuj povas aliri al tiu dosiero aŭ dosierujo)",
    "Path" : "Vojo",
    "_%n byte_::_%n bytes_" : ["%n bajto","%n bajtoj"],
    "Favorited" : "Pliŝatitaj",
    "Favorite" : "Pliŝatata",
    "You can only favorite a single file or folder at a time" : "Vi povas samtempe pliŝatigi nur unu dosieron aŭ dosierujon",
    "New folder" : "Nova dosierujo",
    "Upload file" : "Alŝuti dosieron",
    "Not favorited" : "Ne pliŝatitaj",
    "Remove from favorites" : "Malpliŝatigi",
    "Add to favorites" : "Pliŝatigi",
    "An error occurred while trying to update the tags" : "Okazis eraro dum provo ĝisdatigi la etikedojn",
    "Added to favorites" : "Aldonita al pliŝatataĵoj",
    "Removed from favorites" : "Forigita el pliŝataĵoj",
    "You added {file} to your favorites" : "Vi aldonis {file} al viaj pliŝataĵoj",
    "You removed {file} from your favorites" : "Vi forigis {file} el viaj pliŝataĵoj",
    "File changes" : "Dosierŝanĝoj",
    "Created by {user}" : "Kreita de {user}",
    "Changed by {user}" : "Ŝanĝita de {user}",
    "Deleted by {user}" : "Forigita de {user}",
    "Restored by {user}" : "Restaŭrita de {user}",
    "Renamed by {user}" : "Alinomita de {user}",
    "Moved by {user}" : "Movita de {user}",
    "\"remote user\"" : "„fora uzanto“",
    "You created {file}" : "Vi kreis „{file}“",
    "You created an encrypted file in {file}" : "Vi kreis ĉifritan dosieron en {file}",
    "{user} created {file}" : "{user} kreis {file}",
    "{user} created an encrypted file in {file}" : "{user} kreis ĉifritan dosieron en {file}",
    "{file} was created in a public folder" : "{file} kreiĝis en publika dosierujo",
    "You changed {file}" : "Vi ŝanĝis {file}",
    "You changed an encrypted file in {file}" : "Vi ŝanĝis ĉifritan dosieron en {file}",
    "{user} changed {file}" : "{user} ŝanĝis {file}",
    "{user} changed an encrypted file in {file}" : "{user} ŝanĝis ĉifritan dosieron en {file}",
    "You deleted {file}" : "Vi forigis {file}",
    "You deleted an encrypted file in {file}" : "Vi forigis ĉifritan dosieron en {file}",
    "{user} deleted {file}" : "{user} forigis {file}",
    "{user} deleted an encrypted file in {file}" : "{user} forigis ĉifritan dosieron en {file}",
    "You restored {file}" : "Vi restaŭris {file}",
    "{user} restored {file}" : "{user} restaŭris {file}",
    "You renamed {oldfile} to {newfile}" : "Vi alinomis {oldfile} al {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} alinomis {oldfile} al {newfile}",
    "You moved {oldfile} to {newfile}" : "Vi movis {oldfile} al {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} movis {oldfile} al {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Dosiero aldoniĝis aŭ foriĝis el viaj <strong>pliŝataĵoj</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Dosiero aŭ dosierujo <strong>ŝanĝiĝis</strong> aŭ <strong>alinomiĝis</strong>",
    "A new file or folder has been <strong>created</strong>" : "Nova dosiero aŭ dosierujo <strong>kreiĝis</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Dosiero aŭ dosierujo <strong>foriĝis</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limigi sciigojn pri kreo aŭ ŝanĝo de viaj <strong>pliŝatataj dosieroj</strong> <em>(nur en la fluo)</em>",
    "A file or folder has been <strong>restored</strong>" : "Dosiero aŭ dosierujo <strong>restaŭrita</strong>",
    "Unlimited" : "Senlima",
    "Upload (max. %s)" : "Alŝuti (maks. %s)",
    "File Management" : "Dosieradministrado",
    "Error while loading the file data" : "Eraro dum ŝargo de la dosierdatumoj",
    "Unable to change the favourite state of the file" : "Ne eblas ŝanĝi la staton pri pliŝatataĵo de la dosiero",
    "%s used" : "%s uzataj",
    "%s%% of %s used" : "%s%% el %s uzataj",
    "%1$s of %2$s used" : "%1$s uzataj el %2$s",
    "Settings" : "Agordo",
    "Show hidden files" : "Montri kaŝitajn dosierojn",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Uzu tiun adreson por <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">atingi viajn dosierojn per WebDAV</a>",
    "Toggle grid view" : "Baskuligi kradan vidon",
    "No files in here" : "Neniu dosiero ĉi tie",
    "Upload some content or sync with your devices!" : "Alŝutu iom da enhavo aŭ sinkronigu kun viaj aparatoj!",
    "No entries found in this folder" : "Neniu enigo troviĝis en ĉi tiu dosierujo",
    "Select all" : "Elekti ĉion",
    "Upload too large" : "Alŝuto tro granda",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "La dosieroj, kiujn vi provas alŝuti, transpasas la maksimuman grandon por dosieralŝutoj en ĉi tiu servilo.",
    "No favorites yet" : "Ankoraŭ neniu pliŝataĵo",
    "Files and folders you mark as favorite will show up here" : "Dosieroj kaj dosierujoj, kiujn vi markas kiel pliŝataĵoj, aperos ĉi tie",
    "Tags" : "Etikedoj",
    "Deleted files" : "Forigitaj dosieroj",
    "Shares" : "Kunhavigoj",
    "Shared with others" : "Kunhavata kun aliaj",
    "Shared with you" : "Kunhavata kun vi",
    "Shared by link" : "Kunhavata per ligilo",
    "Deleted shares" : "Forigitaj kunhavigoj",
    "Text file" : "Tekstodosiero",
    "New text file.txt" : "Nova tekstodosiero.txt",
    "File handling" : "Dosiertraktado",
    "Maximum upload size" : "Maksimuma alŝutogrando",
    "max. possible: " : "maks. ebla: ",
    "Save" : "Konservi",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Per PHP-FPM, ŝanĝoj povas postuli 5 minutojn por aplikiĝi.",
    "Missing permissions to edit from here." : "Mankas permesoj por redakti ekde ĉi tie.",
    "Cancel upload" : "Nuligi alŝuton",
    "%s of %s used" : "%s uzataj el %s",
    "%1$s%% of %2$s used" : "%1$s%% el %2$s uzataj"
},
"nplurals=2; plural=(n != 1);");
